==> ckan-2.2.tar.gz: ckan-2.2/ckan/public/base/i18n/ja.js <==
{
  "": {
    "domain": "ckan",
    "lang": "ja",
    "plural-forms": "nplurals=1; plural=0;"
  },
  "An Error Occurred": [
    null,
    "エラーが発生しました"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "このアクションを実行してよろしいですか？"
  ],
  "Cancel": [
    null,
    "キャンセル"
  ],
  "Confirm": [
    null,
    "確認"
  ],
  "Edit": [
    null,
    "編集"
  ],
  "Failed to load data API information": [
    null,
    "データAPIの情報の読み込みに失敗しました"
  ],
  "Follow": [
    null,
    "フォロー"
  ],
  "Hide": [
    null,
    "隠す"
  ],
  "Image": [
    null,
    "画像"
  ],
  "Input is too short, must be at least one character": [
    null,
    "1文字以上入力してください"
  ],
  "Link": [
    null,
    "リンク"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Web上のURLへリンク(APIへのリンク可)"
  ],
  "Loading...": [
    null,
    "ロード中..."
  ],
  "No matches found": [
    null,
    "見つかりません"
  ],
  "Please Confirm Action": [
    null,
    "アクションを確認してください"
  ],
  "Remove": [
    null,
    "削除"
  ],
  "Reorder resources": [
    null,
    "リソースを再整列"
  ],
  "Reset this": [
    null,
    "これを初期化"
  ],
  "Resource uploaded": [
    null,
    "リソースがアップロードされました"
  ],
  "Save order": [
    null,
    "並び順を保存"
  ],
  "Saving...": [
    null,
    "保存中..."
  ],
  "Show more": [
    null,
    "もっとみる"
  ],
  "Start typing…": [
    null,
    "入力開始..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "保存されていない変更があります"
  ],
  "There is no API data to load for this resource": [
    null,
    "このリソースのデータを読み込むためのAPIがありません"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "アップロードを許可できません"
  ],
  "Unable to get data for uploaded file": [
    null,
    "アップロードしたファイルからデータを取得できません"
  ],
  "Unable to upload file": [
    null,
    "ファイルをアップロードできません"
  ],
  "Unfollow": [
    null,
    "フォロー解除"
  ],
  "Upload": [
    null,
    "アップロード"
  ],
  "Upload a file": [
    null,
    "ファイルをアップロード"
  ],
  "Upload a file on your computer": [
    null,
    "コンピュータ上のファイルをアップロード"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "ファイルをアップロードしています。ナビゲートを離れてこのアップロードを終了しても良いですか?"
  ],
  "show less": [
    null,
    "少なく表示"
  ],
  "show more": [
    null,
    "もっとみる"
  ]
}

==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/ja.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "ja", 
    "plural-forms": "nplurals=1; plural=0;"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "%(color)s シャツ"
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "%(num)d アイテム"
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "%(num)d 翻訳がありません。"
  ], 
  "Add Filter": [
    null, 
    "フィルター追加"
  ], 
  "An Error Occurred": [
    null, 
    "エラーが発生しました"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "このアクションを実行してよろしいですか？"
  ], 
  "Cancel": [
    null, 
    "キャンセル"
  ], 
  "Confirm": [
    null, 
    "確認"
  ], 
  "Could not load view": [
    null, 
    "ビューを読み込めません"
  ], 
  "DataProxy returned an error": [
    null, 
    "データプロキシでエラーが発生しています"
  ], 
  "DataStore returned an error": [
    null, 
    "データストアでエラーが発生しています"
  ], 
  "Edit": [
    null, 
    "編集"
  ], 
  "Failed to load data API information": [
    null, 
    "データAPIの情報の読み込みに失敗しました"
  ], 
  "File": [
    null, 
    "ファイル"
  ], 
  "Filters": [
    null, 
    "フィルター"
  ], 
  "Follow": [
    null, 
    "フォロー"
  ], 
  "Graph": [
    null, 
    "グラフ"
  ], 
  "Grid": [
    null, 
    "グリッド"
  ], 
  "Hide": [
    null, 
    "隠す"
  ], 
  "Image": [
    null, 
    "画像"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "%(num)d 文字以上入力してください"
  ], 
  "Link": [
    null, 
    "リンク"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Web上のURLへリンク(APIへのリンク可)"
  ], 
  "Loading...": [
    null, 
    "ロード中..."
  ], 
  "Map": [
    null, 
    "マップ"
  ], 
  "No matches found": [
    null, 
    "見つかりません"
  ], 
  "Please Confirm Action": [
    null, 
    "アクションを確認してください"
  ], 
  "Remove": [
    null, 
    "削除"
  ], 
  "Resource uploaded": [
    null, 
    "リソースがアップロードされました"
  ], 
  "Save order": [
    null, 
    "並び順を保存"
  ], 
  "Saving...": [
    null, 
    "保存中..."
  ], 
  "Select a field": [
    null, 
    "フィールドを選択"
  ], 
  "Show more": [
    null, 
    "もっとみる"
  ], 
  "Start typing…": [
    null, 
    "入力開始..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "保存されていない変更があります"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "このリソースのデータを読み込むためのAPIがありません"
  ], 
  "URL": [
    null, 
    "URL"
  ], 
  "Unable to authenticate upload": [
    null, 
    "アップロードを許可できません"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "アップロードしたファイルからデータを取得できません"
  ], 
  "Unable to upload file": [
    null, 
    "ファイルをアップロードできません"
  ], 
  "Unfollow": [
    null, 
    "フォロー解除"
  ], 
  "Upload": [
    null, 
    "アップロード"
  ], 
  "Upload a file": [
    null, 
    "ファイルをアップロード"
  ], 
  "Upload a file on your computer": [
    null, 
    "コンピュータ上のファイルをアップロード"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "ファイルをアップロードしています。ナビゲートを離れてこのアップロードを終了しても良いですか？"
  ], 
  "bar": [
    "bars", 
    "bars"
  ], 
  "error loading view": [
    null, 
    "エラーローディングビュー"
  ], 
  "foo": [
    null, 
    "foo"
  ], 
  "hello %(name)s!": [
    null, 
    "ハロー %(name)s!"
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "%(attr)s の翻訳なし"
  ], 
  "no translation": [
    "no translations", 
    "翻訳なし"
  ]
}
